Index: wp-content/themes/twentyten/footer.php
===================================================================
--- wp-content/themes/twentyten/footer.php	(revision 14753)
+++ wp-content/themes/twentyten/footer.php	(working copy)
@@ -26,7 +26,7 @@
 				<a href="<?php echo home_url( '/' ) ?>" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>" rel="home">
 					<?php bloginfo( 'name' ); ?>
 				</a>
-			</div>
+			</div><!-- #site-info -->
 
 			<div id="site-generator">
 				<?php do_action( 'twentyten_credits' ); ?>
@@ -34,13 +34,14 @@
 						title="<?php esc_attr_e('Semantic Personal Publishing Platform', 'twentyten'); ?>" rel="generator">
 					<?php printf( __('Proudly powered by %s.', 'twentyten'), 'WordPress' ); ?>
 				</a>
-			</div>
+			</div><!-- #site-generator -->
 
 		</div><!-- #colophon -->
 	</div><!-- #footer -->
 
 </div><!-- #wrapper -->
 
+<?php /* Always have wp_footer() just before the closing </body> tag of your theme if you want many plugins to work */  ?>
 <?php wp_footer(); ?>
 
 </body>
Index: wp-content/themes/twentyten/author.php
===================================================================
--- wp-content/themes/twentyten/author.php	(revision 14753)
+++ wp-content/themes/twentyten/author.php	(working copy)
@@ -32,12 +32,12 @@
 					<div id="entry-author-info">
 						<div id="author-avatar">
 							<?php echo get_avatar( get_the_author_meta( 'user_email' ), apply_filters( 'twentyten_author_bio_avatar_size', 60 ) ); ?>
-						</div><!-- #author-avatar 	-->
+						</div><!-- #author-avatar -->
 						<div id="author-description">
 							<h2><?php printf( __( 'About %s', 'twentyten' ), get_the_author() ); ?></h2>
 							<?php the_author_meta( 'description' ); ?>
 						</div><!-- #author-description	-->
-					</div><!-- .entry-author-info -->
+					</div><!-- #entry-author-info -->
 <?php endif; ?>
 
 <?php
Index: wp-content/themes/twentyten/search.php
===================================================================
--- wp-content/themes/twentyten/search.php	(revision 14753)
+++ wp-content/themes/twentyten/search.php	(working copy)
@@ -29,7 +29,7 @@
 						<p><?php _e( 'Sorry, but nothing matched your search criteria. Please try again with some different keywords.', 'twentyten' ); ?></p>
 						<?php get_search_form(); ?>
 					</div><!-- .entry-content -->
-				</div>
+				</div><!-- #post-0 -->
 <?php endif; ?>
 			</div><!-- #content -->
 		</div><!-- #container -->
Index: wp-content/themes/twentyten/loop.php
===================================================================
--- wp-content/themes/twentyten/loop.php	(revision 14753)
+++ wp-content/themes/twentyten/loop.php	(working copy)
@@ -7,6 +7,12 @@
  * http://codex.wordpress.org/Template_Tags to understand
  * the tags used in it.
  *
+ * This can be overridden on a template by templat basis
+ * by having your child theme contain a loop-(template file
+ * being used).php. For example loop-index.php would be used
+ * when the index.php template is used.
+ *
+ *
  * @package WordPress
  * @subpackage Twenty_Ten
  * @since Twenty Ten 1.0
@@ -68,7 +74,7 @@
 	$image_img_tag = wp_get_attachment_image( $image->ID, 'thumbnail' );
 ?>
 					<a class="size-thumbnail" href="<?php the_permalink(); ?>"><?php echo $image_img_tag; ?></a>
-				</div>
+				</div><!-- .gallery-thumb -->
 				<p><em><?php printf( __( 'This gallery contains <a %1$s>%2$s photos</a>.', 'twentyten' ),
 						'href="' . get_permalink() . '" title="' . sprintf( esc_attr__( 'Permalink to %s', 'twentyten' ), the_title_attribute( 'echo=0' ) ) . '" rel="bookmark"',
 						$total_images
@@ -82,8 +88,8 @@
 				<span class="meta-sep">|</span>
 				<span class="comments-link"><?php comments_popup_link( __( 'Leave a comment', 'twentyten' ), __( '1 Comment', 'twentyten' ), __( '% Comments', 'twentyten' ) ); ?></span>
 				<?php edit_post_link( __( 'Edit', 'twentyten' ), '<span class="meta-sep">|</span> <span class="edit-link">', '</span>' ); ?>
-			</div><!-- #entry-utility -->
-		</div>
+			</div><!-- .entry-utility -->
+		</div><!-- #post-<?php the_ID(); ?> -->
 
 <?php /* How to display posts in the asides category */ ?>
 
@@ -105,8 +111,8 @@
 				<span class="meta-sep">|</span>
 				<span class="comments-link"><?php comments_popup_link( __( 'Leave a comment', 'twentyten' ), __( '1 Comment', 'twentyten' ), __( '% Comments', 'twentyten' ) ); ?></span>
 				<?php edit_post_link( __( 'Edit', 'twentyten' ), '<span class="meta-sep">|</span> <span class="edit-link">', '</span>' ); ?>
-			</div><!-- #entry-utility -->
-		</div><!-- #post-(id) -->
+			</div><!-- .entry-utility -->
+		</div><!-- #post-<?php the_ID(); ?> -->
 
 <?php /* How to display all other posts. */ ?>
 
@@ -147,7 +153,7 @@
 				<?php endif; ?>
 				<span class="comments-link"><?php comments_popup_link( __( 'Leave a comment', 'twentyten' ), __( '1 Comment', 'twentyten' ), __( '% Comments', 'twentyten' ) ); ?></span>
 				<?php edit_post_link( __( 'Edit', 'twentyten' ), '<span class="meta-sep">|</span> <span class="edit-link">', '</span>' ); ?>
-			</div><!-- #entry-utility -->
+			</div><!-- .entry-utility -->
 		</div><!-- #post-<?php the_ID(); ?> -->
 
 		<?php comments_template( '', true ); ?>
Index: wp-content/themes/twentyten/single.php
===================================================================
--- wp-content/themes/twentyten/single.php	(revision 14753)
+++ wp-content/themes/twentyten/single.php	(working copy)
@@ -46,14 +46,14 @@
 								</a>
 							</div><!-- #author-link	-->
 						</div><!-- #author-description -->
-					</div><!-- .entry-author-info -->
+					</div><!-- #entry-author-info -->
 <?php endif; ?>
 
 					<div class="entry-utility">
 						<?php twentyten_posted_in(); ?>
 						<?php edit_post_link( __( 'Edit', 'twentyten' ), '<span class="edit-link">', '</span>' ); ?>
 					</div><!-- .entry-utility -->
-				</div><!-- #post-(id) -->
+				</div><!-- #post-<?php the_ID(); ?> -->
 
 				<div id="nav-below" class="navigation">
 					<div class="nav-previous"><?php previous_post_link( '%link', '<span class="meta-nav">' . _x( '&larr;', 'Previous post link', 'twentyten' ) . '</span> %title' ); ?></div>
Index: wp-content/themes/twentyten/editor-style-rtl.css
===================================================================
--- wp-content/themes/twentyten/editor-style-rtl.css	(revision 14753)
+++ wp-content/themes/twentyten/editor-style-rtl.css	(working copy)
@@ -1,3 +1,9 @@
+/*
+Theme Name: Twenty Ten
+*/
+/*
+RTL style used inside the tiny mce editor to make it a What you see is what you really get editor
+*/
 html .mceContentBody{
 	direction:rtl;
 	unicode-bidi:embed;
Index: wp-content/themes/twentyten/editor-style.css
===================================================================
--- wp-content/themes/twentyten/editor-style.css	(revision 14753)
+++ wp-content/themes/twentyten/editor-style.css	(working copy)
@@ -1,3 +1,9 @@
+/*
+Theme Name: Twenty Ten
+*/
+/*
+Style used inside the tiny mce editor to make it a What you see is what you really get editor
+*/
 html .mceContentBody {
 	max-width:640px;
 }
Index: wp-content/themes/twentyten/comments.php
===================================================================
--- wp-content/themes/twentyten/comments.php	(revision 14753)
+++ wp-content/themes/twentyten/comments.php	(working copy)
@@ -16,7 +16,7 @@
 			<div id="comments">
 <?php if ( post_password_required() ) : ?>
 				<div class="nopassword"><?php _e( 'This post is password protected. Enter the password to view any comments.', 'twentyten' ); ?></div>
-			</div><!-- .comments -->
+			</div><!-- #comments -->
 <?php
 		/* Stop the rest of comments.php from being processed,
 		 * but don't kill the script entirely -- we still have
@@ -40,7 +40,7 @@
 			<div class="navigation">
 				<div class="nav-previous"><?php previous_comments_link( __( '&larr; Older Comments', 'twentyten' ) ); ?></div>
 				<div class="nav-next"><?php next_comments_link( __( 'Newer Comments &rarr;', 'twentyten' ) ); ?></div>
-			</div>
+			</div> <!-- .navigation -->
 <?php endif; // check for comment navigation ?>
 
 			<ol class="commentlist">
@@ -59,7 +59,7 @@
 			<div class="navigation">
 				<div class="nav-previous"><?php previous_comments_link( __( '&larr; Older Comments', 'twentyten' ) ); ?></div>
 				<div class="nav-next"><?php next_comments_link( __( 'Newer Comments &rarr;', 'twentyten' ) ); ?></div>
-			</div>
+			</div><!-- .navigation -->
 <?php endif; // check for comment navigation ?>
 
 <?php else : // or, if we don't have comments:
@@ -70,7 +70,7 @@
 	if ( ! comments_open() ) :
 ?>
 	<p class="nocomments"><?php _e( 'Comments are closed.', 'twentyten' ); ?></p>
-<?php endif; // end ! comments_opened() ?>
+<?php endif; // end ! comments_open() ?>
 
 <?php endif; // end have_comments() ?>
 
Index: wp-content/themes/twentyten/header.php
===================================================================
--- wp-content/themes/twentyten/header.php	(revision 14753)
+++ wp-content/themes/twentyten/header.php	(working copy)
@@ -13,29 +13,30 @@
 <head>
 	<meta charset="<?php bloginfo( 'charset' ); ?>" />
 	<title>
-	<?php
-		if ( is_single() ) {
+	<?php // Returns the title based on the type of page being viewed
+		if ( is_single() ) {	// Single post pages
 			single_post_title(); echo ' | '; bloginfo( 'name' );
-		} elseif ( is_home() || is_front_page() ) {
-			bloginfo( 'name' ); 
-			if( get_bloginfo( 'description' ) ) 
-				echo ' | ' ; bloginfo( 'description' ); 
+		} elseif ( is_home() || is_front_page() ) {  // Both the home page and if using a static front page, the blog post page
+			bloginfo( 'name' );
+			if( get_bloginfo( 'description' ) )
+				echo ' | ' ; bloginfo( 'description' );
 			twentyten_the_page_number();
-		} elseif ( is_page() ) {
+		} elseif ( is_page() ) { // All Pages
 			single_post_title( '' ); echo ' | '; bloginfo( 'name' );
-		} elseif ( is_search() ) {
+		} elseif ( is_search() ) { // Search result pages
 			printf( __( 'Search results for %s', 'twentyten' ), '"'.get_search_query().'"' ); twentyten_the_page_number(); echo ' | '; bloginfo( 'name' );
-		} elseif ( is_404() ) {
+		} elseif ( is_404() ) {  // 404, nothing found pages
 			_e( 'Not Found', 'twentyten' ); echo ' | '; bloginfo( 'name' );
-		} else {
+		} else { // Everything else
 			wp_title( '' ); echo ' | '; bloginfo( 'name' ); twentyten_the_page_number();
 		}
 	?>
 	</title>
 	<link rel="profile" href="http://gmpg.org/xfn/11" />
 	<link rel="stylesheet" type="text/css" media="all" href="<?php bloginfo( 'stylesheet_url' ); ?>" />
-	<?php if ( is_singular() && get_option( 'thread_comments' ) ) wp_enqueue_script( 'comment-reply' ); ?>
+	<?php if ( is_singular() && get_option( 'thread_comments' ) ) wp_enqueue_script( 'comment-reply' );//On pages that have comment forms, we add some javascript to make threaded comments work ?>
 	<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>" />
+	<?php /* Always have wp_head() in the </head> of your theme if you want many plugins to work */  ?>
 	<?php wp_head(); ?>
 </head>
 
@@ -66,7 +67,9 @@
 			</div><!-- #branding -->
 
 			<div id="access" role="navigation">
+			  <?php /*  Allow screen readers / text browsers to skip the navigation menu and get right to the good stuff */ ?>
 				<div class="skip-link screen-reader-text"><a href="#content" title="<?php esc_attr_e( 'Skip to content', 'twentyten' ); ?>"><?php _e( 'Skip to content', 'twentyten' ); ?></a></div>
+				<?php /* Our navigation menu.  If one isn't filled out, wp_nav_menu falls back to wp_page_menu.  The menu assiged to the primary position is the one used.  If none is assigned, the menu with the lowest ID is used.  */ ?>
 				<?php wp_nav_menu( array( 'sort_column' => 'menu_order', 'container_class' => 'menu-header', 'theme_location' => 'primary' ) ); ?>
 			</div><!-- #access -->
 		</div><!-- #masthead -->
Index: wp-content/themes/twentyten/attachment.php
===================================================================
--- wp-content/themes/twentyten/attachment.php	(revision 14753)
+++ wp-content/themes/twentyten/attachment.php	(working copy)
@@ -51,7 +51,7 @@
 										$metadata['height']
 									)
 								);
-							}							
+							}
 						?>
 						<?php edit_post_link( __( 'Edit', 'twentyten' ), '<span class="meta-sep">|</span> <span class="edit-link">', '</span>' ); ?>
 					</div><!-- .entry-meta -->
@@ -82,11 +82,11 @@
 <?php else : ?>
 						<a href="<?php echo wp_get_attachment_url(); ?>" title="<?php echo esc_attr( get_the_title() ); ?>" rel="attachment"><?php echo basename( get_permalink() ); ?></a>
 <?php endif; ?>
-						</div>
+						</div><!-- .entry-attachment -->
 						<div class="entry-caption"><?php if ( !empty( $post->post_excerpt ) ) the_excerpt(); ?></div>
 
 <?php the_content( __( 'Continue reading <span class="meta-nav">&rarr;</span>', 'twentyten' ) ); ?>
-<?php wp_link_pages( array( 'before' => '<div class="page-link">' . __( 'Pages:', 'twentyten' ), 'after' => '</div>' ) ); ?>
+<?php wp_link_pages( array( 'before' => '<div class="page-link">' . __( 'Pages:', 'twentyten' ), 'after' => '</div><!-- .page-link -->' ) ); ?>
 
 					</div><!-- .entry-content -->
 

Index: wp-content/themes/twentyten/functions.php
===================================================================
--- wp-content/themes/twentyten/functions.php	(revision 14753)
+++ wp-content/themes/twentyten/functions.php	(working copy)
@@ -31,7 +31,7 @@
  * }
  * </code>
  *
- * For more information on hooks, see http://codex.wordpress.org/Plugin_API.
+ * For more information on hooks and filters, see http://codex.wordpress.org/Plugin_API.
  *
  * @package WordPress
  * @subpackage Twenty_Ten
@@ -110,7 +110,7 @@
 	define( 'HEADER_IMAGE_HEIGHT', apply_filters( 'twentyten_header_image_height', 198 ) );
 
 	// We'll be using post thumbnails for custom header images on posts and pages.
 	// We want them to be 940 pixels wide by 198 pixels tall (larger images will be auto-cropped to fit).
 	set_post_thumbnail_size( HEADER_IMAGE_WIDTH, HEADER_IMAGE_HEIGHT, true );
 
 	// Don't support text inside the header image.
@@ -133,43 +133,43 @@
 		'cherryblossom' => array(
 			'url' => '%s/images/headers/cherryblossoms.jpg',
 			'thumbnail_url' => '%s/images/headers/cherryblossoms-thumbnail.jpg',
-			/* translators: header image description */			
+			/* translators: header image description */
 			'description' => __( 'Cherry Blossoms', 'twentyten' )
 		),
 		'concave' => array(
 			'url' => '%s/images/headers/concave.jpg',
 			'thumbnail_url' => '%s/images/headers/concave-thumbnail.jpg',
-			/* translators: header image description */			
+			/* translators: header image description */
 			'description' => __( 'Concave', 'twentyten' )
 		),
 		'fern' => array(
 			'url' => '%s/images/headers/fern.jpg',
 			'thumbnail_url' => '%s/images/headers/fern-thumbnail.jpg',
-			/* translators: header image description */			
+			/* translators: header image description */
 			'description' => __( 'Fern', 'twentyten' )
 		),
 		'forestfloor' => array(
 			'url' => '%s/images/headers/forestfloor.jpg',
 			'thumbnail_url' => '%s/images/headers/forestfloor-thumbnail.jpg',
-			/* translators: header image description */			
+			/* translators: header image description */
 			'description' => __( 'Forest Floor', 'twentyten' )
 		),
 		'inkwell' => array(
 			'url' => '%s/images/headers/inkwell.jpg',
 			'thumbnail_url' => '%s/images/headers/inkwell-thumbnail.jpg',
-			/* translators: header image description */			
+			/* translators: header image description */
 			'description' => __( 'Inkwell', 'twentyten' )
 		),
 		'path' => array(
 			'url' => '%s/images/headers/path.jpg',
 			'thumbnail_url' => '%s/images/headers/path-thumbnail.jpg',
-			/* translators: header image description */			
+			/* translators: header image description */
 			'description' => __( 'Path', 'twentyten' )
 		),
 		'sunset' => array(
 			'url' => '%s/images/headers/sunset.jpg',
 			'thumbnail_url' => '%s/images/headers/sunset-thumbnail.jpg',
-			/* translators: header image description */			
+			/* translators: header image description */
 			'description' => __( 'Sunset', 'twentyten' )
 		)
 	) );
@@ -288,7 +288,7 @@
 		<div class="comment-author vcard">
 			<?php echo get_avatar( $comment, 40 ); ?>
 			<?php printf( __( '%s <span class="says">says:</span>', 'twentyten' ), sprintf( '<cite class="fn">%s</cite>', get_comment_author_link() ) ); ?>
-		</div>
+		</div><!-- .comment-author .vcard -->
 		<?php if ( $comment->comment_approved == '0' ) : ?>
 			<em><?php _e( 'Your comment is awaiting moderation.', 'twentyten' ); ?></em>
 			<br />
@@ -299,14 +299,14 @@
 				/* translators: 1: date, 2: time */
 				printf( __( '%1$s at %2$s', 'twentyten' ), get_comment_date(),  get_comment_time() ); ?></a><?php edit_comment_link( __( '(Edit)', 'twentyten' ), ' ' );
 			?>
-		</div>
+		</div><!-- .comment-meta .commentmetadata -->
 
 		<div class="comment-body"><?php comment_text(); ?></div>
 
 		<div class="reply">
 			<?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
-		</div>
-	</div>
+		</div><!-- .reply -->
+	</div><!-- #comment-<?php comment_ID(); ?>  -->
 
 	<?php else : ?>
 	<li class="post pingback">
@@ -325,7 +325,7 @@
  * @uses register_sidebar
  */
 function twentyten_widgets_init() {
-	// Area 1
+	// Area 1 located at the top of the sidebar
 	register_sidebar( array(
 		'name' => __( 'Primary Widget Area', 'twentyten' ),
 		'id' => 'primary-widget-area',
@@ -336,7 +336,7 @@
 		'after_title' => '</h3>',
 	) );
 
-	// Area 2
+	// Area 2 located below the Primary Widget Area in the sidebar.  Empty by default and design
 	register_sidebar( array(
 		'name' => __( 'Secondary Widget Area', 'twentyten' ),
 		'id' => 'secondary-widget-area',
@@ -347,7 +347,7 @@
 		'after_title' => '</h3>',
 	) );
 
-	// Area 3
+	// Area 3 located in the footer.  Empty by default
 	register_sidebar( array(
 		'name' => __( 'First Footer Widget Area', 'twentyten' ),
 		'id' => 'first-footer-widget-area',
@@ -358,7 +358,7 @@
 		'after_title' => '</h3>',
 	) );
 
-	// Area 4
+	// Area 4 located in the footer.  Empty by default
 	register_sidebar( array(
 		'name' => __( 'Second Footer Widget Area', 'twentyten' ),
 		'id' => 'second-footer-widget-area',
@@ -369,7 +369,7 @@
 		'after_title' => '</h3>',
 	) );
 
-	// Area 5
+	// Area 5 located in the footer.  Empty by default
 	register_sidebar( array(
 		'name' => __( 'Third Footer Widget Area', 'twentyten' ),
 		'id' => 'third-footer-widget-area',
@@ -380,7 +380,7 @@
 		'after_title' => '</h3>',
 	) );
 
-	// Area 6
+	// Area 6 located in the footer.  Empty by default
 	register_sidebar( array(
 		'name' => __( 'Fourth Footer Widget Area', 'twentyten' ),
 		'id' => 'fourth-footer-widget-area',
@@ -422,13 +422,13 @@
 			esc_attr( get_the_time() ),
 			get_the_date()
 		),
-		sprintf( '</span> <span class="author vcard"><a class="url fn n" href="%1$s" title="%2$s">%3$s</a></span>', 
+		sprintf( '</span> <span class="author vcard"><a class="url fn n" href="%1$s" title="%2$s">%3$s</a></span>',
 			get_author_posts_url( get_the_author_meta( 'ID' ) ),
 			sprintf( esc_attr__( 'View all posts by %s', 'twentyten' ), get_the_author() ),
 			get_the_author()
 		)
 	);
-	
+
 }
 endif;
 
@@ -453,6 +453,6 @@
 		$tag_list,
 		get_permalink(),
 		the_title_attribute( 'echo=0' )
-	);	
+	);
 }
 endif;
@@ -110,7 +110,7 @@
 
 	// We'll be using post thumbnails for custom header images on posts and pages.
-	// We want them to be 940 pixels wide by 198 pixels tall (larger images will be auto-cropped to fit).
+	// We want them to be 940 pixels wide by 198 pixels tall (larger images will be auto-cropped to fit, smaller ones will be ignored. See header.php).
 	set_post_thumbnail_size( HEADER_IMAGE_WIDTH, HEADER_IMAGE_HEIGHT, true );
 